import { singleton } from '../decorators/singleton'
import { GameInfo } from '../models/GameInfo'

export class GameMiniInfo {
  public appId: string
  public appSecret: string

  constructor(appId: string, appSecret: string) {
    this.appId = appId
    this.appSecret = appSecret
  }
}

@singleton
export class GameInfoCache {
  private _cache: Map<[string, string], GameMiniInfo> = new Map()

  public async init() {
    let games = await GameInfo.find({ deleted: false })
    for (let game of games) {
      const gameId = game.game_id
      for (let p of game.platforms) {
        const channel = p.platform.platform_id
        const appId = p.app_id
        const appSecret = p.app_secret
        this._cache.set([gameId, channel], new GameMiniInfo(appId, appSecret))
      }
    }
  }

  /**
   *
   */
  public async getInfo(channel: string, gameId: string) {
    let info = this._cache.get([gameId, channel])
    if (!info) {
      let games = await GameInfo.find({ deleted: false, game_id: gameId, 'platforms.platform.platform_id': channel })
      if (games?.length > 0) {
        let game = games[0]
        let platform = game.platforms.find(o => o.platform.platform_id === channel)
        if (platform) {
          info = new GameMiniInfo(platform.app_id, platform.app_secret)
          this._cache.set([gameId, channel], info)
        }
      }
    }
    return info
  }
}
