import BaseController from '../common/base.controller'
import { role, router } from '../decorators/router'
import { ZanInfo } from '../models/ZanInfo'
import { ZError } from '../common/ZError'
import { AccountCollect } from '../models/AccountCollect'

class GameExtController extends BaseController {
  /**
   * 获取游戏点赞信息
   */
  @role('anon')
  @router('post /api/svr/zan/info')
  async reqZanInfosList(req: any) {
    let { accountId, games, type } = req.params
    type = type || 'game'
    let records = await ZanInfo.find({ recordId: { $in: games }, type })
    let results: any = {}
    for (let record of records) {
      let data = record.toJson()
      let did = 0
      if (accountId) {
        did = data.accounts.findIndex(o => o === accountId) > -1 ? 1 : 0
      }
      results[record.recordId] = { count: record.count, did }
    }
    return results
  }

  /**
   * 为一个游戏点赞或取消点赞
   */
  @role('anon')
  @router('post /api/svr/zan/update')
  async updateGameZan(req: any) {
    let { accountId, game, type, act } = req.params
    type = type || 'game'
    if (!accountId) {
      throw new ZError(11, 'accountId needed')
    }
    if (!game) {
      throw new ZError(12, 'gameId needed')
    }
    let record = await ZanInfo.insertOrUpdate({ recordId: game, type }, {})
    const index = record.accounts.indexOf(accountId)
    if (act) {
      if (index > -1) {
        throw new ZError(13, 'already had')
      }
      record.count += 1
      record.accounts.push(accountId)
      await record.save()
    } else {
      if (index === -1) {
        throw new ZError(13, 'not had')
      }
      record.count -= 1
      record.accounts.splice(index, 1)
      await record.save()
    }
    return { count: record.count }
  }

  /**
   * 获取某玩家收藏信息
   */
  @role('anon')
  @router('post /api/svr/collect/list')
  async collectList(req: any) {
    let { accountId, type } = req.params
    type = type || 'game'
    let record = await AccountCollect.insertOrUpdate({ accountId }, {})
    let results = []
    for (let _d of record.games) {
      if (_d.type === type) {
        results.push(_d.recordId)
      }
    }
    return results
  }

  /**
   * 收藏或取消收藏
   */
  @role('anon')
  @router('post /api/svr/collect/update')
  async updateCollect(req: any) {
    let { accountId, game, type, act } = req.params
    type = type || 'game'
    if (!accountId) {
      throw new ZError(11, 'accountId needed')
    }
    if (!game) {
      throw new ZError(12, 'gameId needed')
    }
    let record = await AccountCollect.insertOrUpdate({ accountId }, {})
    let index = record.games.findIndex(o => o.recordId === game && o.type === type)
    let exists = index > -1
    if (act) {
      if (exists) {
        throw new ZError(13, 'already add')
      }
      record.games.push({ recordId: game, type })
    } else {
      if (!exists) {
        throw new ZError(13, 'not add')
      }
      record.games.splice(index, 1)
    }
    await record.save()
    return {}
  }

  @role('anon')
  @router('get /api/svr/tmp/:nid')
  async tmpNftJson(req: any) {
    return {
      name: 'NFT name',
      description: 'NFT description',
      image: 'https://www.cebg.games/img/n_miffy.d1d472aa.png',
      strength: 20,
      nt: 1,
    }
  }
}
