import { role, router } from '../decorators/router'
import BaseController from '../common/base.controller'
import { checkAccountId, parseGameAccountId } from '../utils/string.util'
import { ZError } from '../common/ZError'
import { SubscribeRecord } from '../models/SubscribeRecord'
import { getSubscribeInfo } from '../services/jcfw.svr'
import { sendSubscribeMessage } from '../services/subscribe.svr'
import { isToday } from '../utils/time.util'

class SubscribeController extends BaseController {
  @role('anon')
  @router('post /api/svr/:accountId/send_subscribe_msg')
  async sendSubscribeMsg(req: any) {
    let { accountId, type } = req.params
    let record = await SubscribeRecord.findOne({ accountId, type })
    if (!record || record.count < 1) {
      throw new ZError(20, '没有可用的模板id')
    }
    if (isToday(record.lastCheck)) {
      throw new ZError(21, '今天不需要发送')
    }
    const result = await sendSubscribeMessage({ accountId, type })
    record.lastCheck = Date.now()
    record.lastSend = Date.now()
    await record.save()
    return { msgid: result.msgid }
  }

  @role('anon')
  @router('post /api/svr/:accountId/update_subscribe')
  async updateSubscribeStata(req: any) {
    let { accountId, templateids, counts } = req.params
    if (!accountId || !templateids) {
      throw new ZError(11, 'params mismatch')
    }
    if (!checkAccountId(accountId)) {
      throw new ZError(10, 'accountId error')
    }
    counts = counts || []
    let { gameId, channel, openId } = parseGameAccountId(accountId)
    for (let i = 0, l = templateids.length; i < l; i++) {
      const templateId = templateids[i]
      let record
      if (templateId.indexOf('jsub_') >= 0) {
        const cfg = await getSubscribeInfo({ gameId, channel, type: templateId })
        if (cfg.type && cfg.templateId) {
          record = await SubscribeRecord.insertOrUpdate(
            { gameId, channel, accountId: accountId, templateId: cfg.templateId, type: cfg.type },
            {},
          )
        }
      } else {
        const cfg = await getSubscribeInfo({ gameId, channel, templateId })
        if (cfg.type && cfg.templateId) {
          record = await SubscribeRecord.insertOrUpdate(
            { gameId, channel, accountId: accountId, templateId: cfg.templateId, type: cfg.type },
            {},
          )
        }
      }
      if (record) {
        const count = counts[i] || 0
        if (count > 0) {
          record.count += 1
        }
        record.lastCheck = Date.now()
        await record.save()
      }
    }
    return {}
  }
}
