import { dbconn } from '../decorators/dbconn'
import { getModelForClass, index, modelOptions, prop, ReturnModelType } from '@typegoose/typegoose'
import { BaseModule } from './Base'
import { customAlphabet } from 'nanoid'
const nanoid = customAlphabet('2345678abcdefghjkmnpqrstwxy', 32)

const jsonExcludeKeys = ['updatedAt', '__v', '_id', 'createdAt', 'isBot', 'type']

class RecordInfo {
  @prop()
  public recordId: string
  @prop()
  public type: string
}
/**
 * 存储用户收藏信息
 */
@dbconn()
@index({ accountId: 1 }, { unique: true })
@modelOptions({
  schemaOptions: { collection: 'account_collect', timestamps: true },
})
class AccountCollectClass extends BaseModule {
  @prop()
  accountId: string
  @prop({ type: () => [RecordInfo], default: [] })
  games: RecordInfo[]

  public toJson(): any {
    let result: any = {}
    // @ts-ignore
    for (let key in this._doc) {
      if (jsonExcludeKeys.indexOf(key) == -1) {
        result[key] = this[key]
      }
    }
    return result
  }
}

export const AccountCollect = getModelForClass(AccountCollectClass, { existingConnection: AccountCollectClass.db })
