import { BaseModule } from './Base'
import { dbconn } from '../decorators/dbconn'
import { getModelForClass, modelOptions, prop, Severity, mongoose, index } from '@typegoose/typegoose'

const jsonExcludeKeys = ['updatedAt', '__v', '_id', 'createdAt', 'isBot', 'type', 'inited']

@dbconn()
@index({ oldGameId: 1 }, { unique: true })
@modelOptions({
  schemaOptions: { collection: 'jump_game_cache', timestamps: true },
  options: { allowMixed: Severity.ALLOW },
})
class GameCacheClass extends BaseModule {
  @prop()
  public oldGameId: string

  @prop({ type: mongoose.Schema.Types.Mixed })
  public jumpGame: any

  @prop({ type: mongoose.Schema.Types.Mixed })
  public dlcList: any

  @prop({ type: mongoose.Schema.Types.Mixed })
  public jumpGameExt: any

  @prop({ type: mongoose.Schema.Types.Mixed })
  public otherPlatVersion: any

  @prop({ default: 0 })
  public lastupdate: number

  public toJson(): any {
    let result: any = {}
    // @ts-ignore
    for (let key in this._doc) {
      if (jsonExcludeKeys.indexOf(key) == -1) {
        result[key] = this[key]
      }
    }
    return result
  }
}

export const GameCache = getModelForClass(GameCacheClass, {
  existingConnection: GameCacheClass.db,
})
