import { BaseModule } from './Base'
import { dbconn } from '../decorators/dbconn'
import { getModelForClass, modelOptions, prop, Severity, mongoose } from '@typegoose/typegoose'
import { parseGameAccountId } from '../utils/string.util'

@dbconn()
@modelOptions({
  schemaOptions: { collection: 'subscribe_history', timestamps: true },
  options: { allowMixed: Severity.ALLOW },
})
class SubscribeHistoryClass extends BaseModule {
  @prop()
  public gameId: string
  @prop()
  public channel: string
  @prop()
  public accountId: string
  @prop()
  public templateId: string

  @prop({ type: mongoose.Schema.Types.Mixed })
  public result: any

  public static async log(accountId: string, templateId: string, result: any) {
    let record = new SubscribeHistory()
    record.accountId = accountId
    record.templateId = templateId
    record.result = result
    let { gameId, channel } = parseGameAccountId(accountId)
    record.gameId = gameId
    record.channel = channel
    await record.save()
  }
}

export const SubscribeHistory = getModelForClass(SubscribeHistoryClass, {
  existingConnection: SubscribeHistoryClass.db,
})
