import { dbconn } from '../decorators/dbconn'
import { getModelForClass, index, modelOptions, prop } from '@typegoose/typegoose'
import { BaseModule } from './Base'

const jsonExcludeKeys = ['updatedAt', '__v', '_id', 'createdAt', 'isBot', 'type']

/**
 * 存储游戏, 文章等的点赞信息
 */
@dbconn()
@index({ recordId: 1, type: 1 }, { unique: true })
@modelOptions({
  schemaOptions: { collection: 'zan_info', timestamps: true },
})
class ZanInfoClass extends BaseModule {
  @prop()
  recordId: string

  @prop()
  type: string

  @prop({ default: 0 })
  count: number

  @prop({ type: () => [String], default: [] })
  accounts: string[]

  public toJson(): any {
    let result: any = {}
    // @ts-ignore
    for (let key in this._doc) {
      if (jsonExcludeKeys.indexOf(key) == -1) {
        result[key] = this[key]
      }
    }
    return result
  }
}

export const ZanInfo = getModelForClass(ZanInfoClass, { existingConnection: ZanInfoClass.db })
