import { singleton } from '../decorators/singleton'
import * as schedule from 'node-schedule'
import { SubscribeRecord } from '../models/SubscribeRecord'
import { todayStart } from '../utils/time.util'
import { sendSubscribeMessage } from '../services/subscribe.svr'

@singleton
export default class SubscribeSchedule {
  async parseAllRecord() {
    let records = await SubscribeRecord.find({ count: { $gt: 0 }, lastCheck: { $lt: todayStart() } })
    let sendSet: Set<string> = new Set()
    for (let record of records) {
      if (sendSet.has(record.accountId)) {
        continue
      }
      try {
        await sendSubscribeMessage({ accountId: record.accountId, type: record.type })
        record.lastCheck = Date.now()
        record.lastSend = Date.now()
        record.count -= 1
        sendSet.add(record.accountId)
        await record.save()
      } catch (err) {
        console.log(err)
      }
    }
  }
  scheduleAll() {
    const job = schedule.scheduleJob('1 0 20 * * *', async () => {
      await this.parseAllRecord()
    })
  }
}
