import { checkAccountId, parseGameAccountId } from '../utils/string.util'
import { ZError } from '../common/ZError'
import { GameInfoCache } from '../cache/GameInfoCache'
import { getSubscribeInfo, getSubscribeMsg } from './jcfw.svr'
import { sendWxSubscribeMessage } from './wechat/Wechat'
import { SubscribeHistory } from '../models/SubscribeHistory'

export async function sendSubscribeMessage({
  accountId,
  type,
  templateId,
}: {
  accountId: string
  type?: string
  templateId?: string
}) {
  if (!checkAccountId(accountId)) {
    throw new ZError(10, 'accountId error')
  }
  let { gameId, channel, openId } = parseGameAccountId(accountId)
  if (channel !== '6001') {
    throw new ZError(12, 'this platform can`t send subscribe msg')
  }
  if (!type && !templateId) {
    throw new ZError(13, 'no msg type specify')
  }
  let info = await new GameInfoCache().getInfo(channel, gameId)
  if (!info) {
    throw new ZError(11, 'game cfg not found')
  }
  const cfg = await getSubscribeInfo({ gameId, channel, type, templateId })
  if (!cfg.type || !cfg.templateId) {
    throw new ZError(14, 'subscribe cfg not found')
  }
  const msgData = await getSubscribeMsg(gameId, channel, cfg.type)
  if (!msgData) {
    throw new ZError(15, 'msg cfg not found')
  }
  const result = await sendWxSubscribeMessage({
    appId: info.appId,
    appSecret: info.appSecret,
    openId,
    templateId: cfg.templateId,
    data: msgData,
  })
  await SubscribeHistory.log(accountId, cfg.templateId, result.data)
  if (result?.data?.errcode) {
    throw new ZError(result.data.errcode, result.data.errmsg)
  }
  return result.data
}
