import { singleton } from '../../decorators/singleton'

export class WxTokenClass {
  public token: string
  public expire: number

  constructor(token: string, expire: number) {
    this.token = token
    this.expire = expire
  }
}
/**
 * 用于缓存所有题目的分类
 */
@singleton
export class WxTokenCache {
  private _cache: Map<string, WxTokenClass> = new Map()

  /**
   * 根据id获取分类名
   * @param {string} appId
   * @return {string}
   */
  public getToken(appId: string): string | null {
    if (!this._cache.has(appId)) {
      return null
    }
    let data = this._cache.get(appId)
    if (data.expire - Date.now() < 1200 * 1000) {
      return null
    } else {
      return data.token
    }
  }

  public updateToken(appId: string, token: string, exptime: number) {
    console.log(`update token for ${appId}, exptime: ${exptime}`)
    let expire = Date.now() + exptime * 1000
    let data = new WxTokenClass(token, expire)
    this._cache.set(appId, data)
  }
}
