export const ONE_DAY_MILLISECOND = 1000 * 3600 * 24
/**
 * 获取n天前的time
 * @param {number} day
 * @return {number}
 */
export function timeBeforeDay(day: number): number {
  let time = Date.now()
  return time - day * ONE_DAY_MILLISECOND
}

//间隔天数
export function calcBetweenDays(time1: number, time2: number) {
  let v1 = Math.floor(time1 / ONE_DAY_MILLISECOND)
  let v2 = Math.floor(time2 / ONE_DAY_MILLISECOND)
  return Math.abs(v1 - v2)
}

/**
 * 判断是否是今天
 * @param {number} time
 * @return {boolean}
 */
export function isToday(time: number) {
  return new Date().toDateString() === new Date(time).toDateString()
}

/**
 * 今天开始的时间
 * @return {number}
 */
export function todayStart() {
  return new Date(new Date().toLocaleDateString()).getTime()
}

/**
 * 今天结束的时间
 * @return {number}
 */
export function todayEnd() {
  return todayStart() + ONE_DAY_MILLISECOND - 1
}

/**
 * 获取本周第一天和最后一天(周一开始)
 * @return {{startDay: string, endDay: string}}
 */
export function getThisWeekData() {
  return weekData(0)
}

/**
 * 获取前后n周的周一和周日的日期
 * @param {number} n  0为当前周, 1为下一周, -1为上周
 * @return {{startDay: string, endDay: string}}
 */
export function weekData(n: number) {
  const weekData = { startDay: '', endDay: '' }
  const date = new Date()
  // 上周一的日期
  date.setDate(date.getDate() + 7 * n - date.getDay() + 1)
  weekData.startDay = date.getFullYear() + '-' + (date.getMonth() + 1) + '-' + date.getDate()

  // 上周日的日期
  date.setDate(date.getDate() + 6)
  weekData.endDay = date.getFullYear() + '-' + (date.getMonth() + 1) + '-' + date.getDate()
  return weekData
}
